@@ -1838,3 +1838,143 @@ func TestValidateCloudRunLocation(t *testing.T) {
 		})
 	}
 }
+
+func TestValidateCustomActions(t *testing.T) {
+	tests := []struct {
+		description string
+		shouldErr   bool
+		errMsg      string
+		cfg         runcontext.RunContext
+	}{
+		{
+			description: "repeated action names in same config",
+			shouldErr:   true,
+			errMsg:      "found duplicate custom action action1. Custom action names must be unique",
+			cfg: runcontext.RunContext{
+				Pipelines: runcontext.NewPipelines(
+					map[string]latest.Pipeline{
+						"default": {
+							CustomActions: []latest.Action{
+								{Name: "action1", Containers: []latest.VerifyContainer{{Name: "container1"}}},
+								{Name: "action1", Containers: []latest.VerifyContainer{{Name: "container2"}}},
+							},
+						},
+					},
+					[]string{"default"}),
+			},
+		},
+		{
+			description: "repeated container names in different actions, same config",
+			shouldErr:   true,
+			errMsg:      "found duplicate container name repeated-container-name in custom action. Container names must be unique",
+			cfg: runcontext.RunContext{
+				Pipelines: runcontext.NewPipelines(
+					map[string]latest.Pipeline{
+						"default": {
+							CustomActions: []latest.Action{
+								{Name: "action1", Containers: []latest.VerifyContainer{{Name: "repeated-container-name"}}},
+								{Name: "action2", Containers: []latest.VerifyContainer{
+									{Name: "repeated-container-name"},
+									{Name: "container1"},
+								}},
+							},
+						},
+					},
+					[]string{"default"}),
+			},
+		},
+		{
+			description: "repeated action names in different configs",
+			shouldErr:   true,
+			errMsg:      "found duplicate custom action cross-module-action. Custom action names must be unique",
+			cfg: runcontext.RunContext{
+				Pipelines: runcontext.NewPipelines(
+					map[string]latest.Pipeline{
+						"config1": {
+							CustomActions: []latest.Action{{Name: "cross-module-action", Containers: []latest.VerifyContainer{{Name: "container1"}}}},
+						},
+						"config2": {
+							CustomActions: []latest.Action{
+								{Name: "cross-module-action", Containers: []latest.VerifyContainer{{Name: "container2"}}},
+								{Name: "action1", Containers: []latest.VerifyContainer{{Name: "container3"}}},
+							},
+						},
+					},
+					[]string{"config1", "config2"}),
+			},
+		},
+		{
+			description: "repeated container names in different configs",
+			shouldErr:   true,
+			errMsg:      "found duplicate container name repeated-container-name in custom action. Container names must be unique",
+			cfg: runcontext.RunContext{
+				Pipelines: runcontext.NewPipelines(
+					map[string]latest.Pipeline{
+						"config1": {
+							CustomActions: []latest.Action{{Name: "action1", Containers: []latest.VerifyContainer{{Name: "repeated-container-name"}}}},
+						},
+						"config2": {
+							CustomActions: []latest.Action{
+								{Name: "action2", Containers: []latest.VerifyContainer{{Name: "container2"}}},
+								{Name: "action3", Containers: []latest.VerifyContainer{{Name: "repeated-container-name"}}},
+							},
+						},
+					},
+					[]string{"config1", "config2"}),
+			},
+		},
+		{
+			description: "unique custom action names and containers across configs",
+			shouldErr:   false,
+			cfg: runcontext.RunContext{
+				Pipelines: runcontext.NewPipelines(
+					map[string]latest.Pipeline{
+						"config1": {
+							CustomActions: []latest.Action{{Name: "action1", Containers: []latest.VerifyContainer{{Name: "container1"}}}},
+						},
+						"config2": {
+							CustomActions: []latest.Action{
+								{Name: "action2", Containers: []latest.VerifyContainer{{Name: "container2"}}},
+								{Name: "action3", Containers: []latest.VerifyContainer{{Name: "container3"}}},
+							},
+						},
+					},
+					[]string{"config1", "config2"}),
+			},
+		},
+		{
+			description: "custom action with two execution modes defined",
+			shouldErr:   true,
+			errMsg:      "custom action action1 have more than one execution mode defined. custom actions must have only one execution mode",
+			cfg: runcontext.RunContext{
+				Pipelines: runcontext.NewPipelines(
+					map[string]latest.Pipeline{
+						"config1": {
+							CustomActions: []latest.Action{{
+								Name: "action1",
+								ExecutionModeConfig: latest.ActionExecutionModeConfig{
+									VerifyExecutionModeType: latest.VerifyExecutionModeType{
+										KubernetesClusterExecutionMode: &latest.KubernetesClusterVerifier{},
+										LocalExecutionMode:             &latest.LocalVerifier{},
+									},
+								},
+								Containers: []latest.VerifyContainer{{Name: "container1"}},
+							}},
+						},
+					},
+					[]string{"config1"}),
+			},
+		},
+	}
+
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			err := ProcessWithRunContext(context.Background(), &test.cfg)
+			t.CheckError(test.shouldErr, err)
+
+			if test.shouldErr {
+				t.CheckErrorContains(test.errMsg, err)
+			}
+		})
+	}
+}
